@@ -25,7 +25,7 @@ test_struct test_threading test_time test_traceback test_unicode
 class Cpython(PythonBuilder):
     """
     Build CPython binaries
-    See https://docs.python.org/3.11/using/configure.html
+    See https://docs.python.org/3/using/configure.html
     """
 
     xenv_CFLAGS_NODIST = "-Wno-unused-command-line-argument"
@@ -72,6 +72,7 @@ class Cpython(PythonBuilder):
         if not self.has_configure_opt("--with-openssl"):
             if self.version >= "3.7" and self.active_module(Openssl):
                 yield f"--with-openssl={self.deps}"
+                yield "--with-openssl-rpath=no"
 
         if not self.has_configure_opt("--with-system-ffi"):
             if self.active_module(LibFFI):
@@ -110,16 +111,18 @@ class Cpython(PythonBuilder):
     def _prepare(self):
         super()._prepare()
         if PPG.target.is_macos:
-            # Forbid pesky usage of /usr/local on macos
-            rx = re.compile(r"^(Doc|Grammar|Lib|Misc|Modules|PC|Tools|msi|.*\.(md|html|man|pro|rst))$")
-            patch_folder(self.m_src_build, r"/(usr|opt)/local\b", self.deps.as_posix(), ignore=rx)
-            setup_py = self.m_src_build / "setup.py"
-            if setup_py.exists():
-                # Special edge case in macosx_sdk_specified() where /usr/local is fine...
-                x = "startswith({q}/usr/{q}) and not path.startswith({q}{p}{q})"
-                special_case = x.replace("(", r"\(").replace(")", r"\)").format(q="['\"]", p=self.deps)
-                restored = x.format(q="'", p='/usr/local')
-                patch_file(setup_py, special_case, restored)
+            brew_path = os.path.join(self.setup.build_context.usr_local, "bin/brew")
+            if os.path.exists(brew_path):
+                # Avoid pollution of static builds via /usr/local on macos
+                rx = re.compile(r"^(Doc|Grammar|Lib|Misc|Modules|PC|Tools|msi|.*\.(md|html|man|pro|rst))$")
+                patch_folder(self.m_src_build, r"/usr/local\b", self.deps.as_posix(), ignore=rx)
+                setup_py = self.m_src_build / "setup.py"
+                if setup_py.exists():
+                    # Special edge case in macosx_sdk_specified() where /usr/local is fine...
+                    x = "startswith({q}/usr/{q}) and not path.startswith({q}{p}{q})"
+                    special_case = x.replace("(", r"\(").replace(")", r"\)").format(q="['\"]", p=self.deps)
+                    restored = x.format(q="'", p='/usr/local')
+                    patch_file(setup_py, special_case, restored)
 
             # Only doable on macos: patch -install_name so produced exes/libs use a relative path
             install_name = "-Wl,-install_name,@executable_path/.."
